"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const fs_1 = require("fs");
const mkdirp = require("mkdirp");
const mustache_1 = require("mustache");
const path_1 = require("path");
const util_1 = require("util");
const config_1 = require("../config");
const command_constants_1 = require("../constants/command.constants");
const docker_constants_1 = require("../constants/docker.constants");
const messages_constants_1 = require("../constants/messages.constants");
const data_1 = require("../libs/data");
const utils_1 = require("../libs/utils");
class Dockerize extends command_1.Command {
    async run() {
        let { flags: userFlags } = this.parse(Dockerize);
        const dockerfilePath = path_1.parse(userFlags.output);
        let environmentInfo;
        const environments = await data_1.parseDataFile(userFlags.data);
        userFlags = await utils_1.promptEnvironmentChoice(userFlags, environments);
        try {
            environmentInfo = await data_1.prepareData(environments, {
                index: userFlags.index,
                name: userFlags.name,
                port: userFlags.port
            }, dockerfilePath.dir);
        }
        catch (error) {
            this.error(error.message);
        }
        if (!utils_1.portIsValid(environmentInfo.port)) {
            this.error(util_1.format(messages_constants_1.Messages.CLI.PORT_IS_NOT_VALID, environmentInfo.port));
        }
        try {
            const dockerFile = mustache_1.render(docker_constants_1.DOCKER_TEMPLATE, {
                port: environmentInfo.port,
                filePath: path_1.parse(environmentInfo.dataFile).base,
                version: config_1.Config.version
            });
            await mkdirp(dockerfilePath.dir);
            await fs_1.promises.writeFile(userFlags.output, dockerFile);
            this.log(messages_constants_1.Messages.CLI.DOCKERIZE_SUCCESS, userFlags.output);
            this.log(messages_constants_1.Messages.CLI.DOCKERIZE_BUILD_COMMAND, dockerfilePath.dir, environmentInfo.name, environmentInfo.port, environmentInfo.port, environmentInfo.name);
        }
        catch (error) {
            this.error(error.message);
        }
    }
}
exports.default = Dockerize;
Dockerize.description = 'Create a Dockerfile to build a self-contained image of a mock API';
Dockerize.examples = [
    '$ mockoon-cli dockerize --data ~/export-data.json --output ./Dockerfile',
    '$ mockoon-cli dockerize --data ~/export-data.json --index 0 --output ./Dockerfile',
    '$ mockoon-cli dockerize --data https://file-server/export-data.json --index 0 --output ./Dockerfile',
    '$ mockoon-cli dockerize --data ~/export-data.json --name "Mock environment" --output ./Dockerfile'
];
Dockerize.flags = Object.assign(Object.assign(Object.assign({}, command_constants_1.commonFlags), command_constants_1.startFlags), { output: command_1.flags.string({
        char: 'o',
        description: 'Generated Dockerfile path and name (e.g. `./Dockerfile`)',
        required: true
    }) });
//# sourceMappingURL=dockerize.js.map