"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const util_1 = require("util");
const command_constants_1 = require("../constants/command.constants");
const messages_constants_1 = require("../constants/messages.constants");
const process_manager_1 = require("../libs/process-manager");
const utils_1 = require("../libs/utils");
class Info extends command_1.Command {
    async run() {
        const { args } = this.parse(Info);
        try {
            const processes = await process_manager_1.ProcessManager.info(args.id);
            if (processes.length) {
                utils_1.logProcesses(processes);
            }
            else {
                this.log(util_1.format(messages_constants_1.Messages.CLI.NO_RUNNING_PROCESS_FOUND, args.id));
            }
        }
        catch (error) {
            this.error(error.message);
        }
        finally {
            process_manager_1.ProcessManager.disconnect();
        }
    }
}
exports.default = Info;
Info.description = 'Display information for a running mock API';
Info.examples = [
    '$ mockoon-cli info 0',
    '$ mockoon-cli info "Mock_environment"'
];
Info.args = [
    {
        name: 'id',
        description: 'Running API pid or name (default: 0)',
        default: 0,
        required: false
    }
];
Info.flags = Object.assign({}, command_constants_1.commonFlags);
//# sourceMappingURL=info.js.map