"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProcessManager = exports.ProcessListManager = void 0;
const jsonfile_1 = require("jsonfile");
const pm2 = require("pm2");
const util_1 = require("util");
const config_1 = require("../config");
/**
 * Manage the file containing the running processes list
 */
exports.ProcessListManager = {
    addProcess: async (configProcess) => {
        const configData = exports.ProcessListManager.getProcesses();
        if (!configData.find((conf) => conf.name === configProcess.name && conf.port === configProcess.port)) {
            configData.push(configProcess);
            return await jsonfile_1.writeFile(config_1.Config.processesFilePath, configData, {
                spaces: 2
            });
        }
    },
    getProcesses: () => {
        let configProcesses = [];
        try {
            configProcesses = jsonfile_1.readFileSync(config_1.Config.processesFilePath);
        }
        catch (error) {
            jsonfile_1.writeFileSync(config_1.Config.processesFilePath, configProcesses);
        }
        return configProcesses;
    },
    updateProcesses: async (processes) => {
        const configProcesses = processes.length > 0 ? exports.ProcessListManager.getProcesses() : [];
        processes.forEach((process) => {
            configProcesses.filter((conf) => conf.name === process.name);
        });
        return await jsonfile_1.writeFile(config_1.Config.processesFilePath, configProcesses, {
            spaces: 2
        });
    },
    deleteProcess: (name) => {
        let configProcesses = exports.ProcessListManager.getProcesses();
        configProcesses = configProcesses.filter((data) => data.name !== name);
        jsonfile_1.writeFileSync(config_1.Config.processesFilePath, configProcesses, { spaces: 2 });
    }
};
/**
 * Promisify PM2 methods
 */
exports.ProcessManager = {
    info: util_1.promisify(pm2.describe.bind(pm2)),
    list: async () => {
        const processes = await util_1.promisify(pm2.list.bind(pm2))();
        await exports.ProcessListManager.updateProcesses(processes);
        return processes;
    },
    start: (util_1.promisify(pm2.start.bind(pm2))),
    delete: util_1.promisify(pm2.delete.bind(pm2)),
    disconnect: pm2.disconnect.bind(pm2)
};
//# sourceMappingURL=process-manager.js.map