"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.promptEnvironmentChoice = exports.portIsValid = exports.portInUse = exports.transformEnvironmentName = exports.logProcesses = void 0;
const cli_ux_1 = require("cli-ux");
const inquirer_1 = require("inquirer");
const isPortReachable = require("is-port-reachable");
const prettyBytes = require("pretty-bytes");
const process_manager_1 = require("./process-manager");
/**
 * Display a list of running processes information
 *
 * @param processes
 */
const logProcesses = (processes) => {
    const configProcesses = process_manager_1.ProcessListManager.getProcesses();
    cli_ux_1.cli.table(processes, {
        name: {
            minWidth: 10
        },
        id: {
            minWidth: 5,
            get: (row) => row.pm_id
        },
        status: {
            minWidth: 10,
            get: (row) => { var _a; return (_a = row.pm2_env) === null || _a === void 0 ? void 0 : _a.status; }
        },
        cpu: {
            minWidth: 7,
            get: (row) => { var _a; return (_a = row.monit) === null || _a === void 0 ? void 0 : _a.cpu; }
        },
        memory: {
            minWidth: 10,
            get: (row) => { var _a; return (((_a = row.monit) === null || _a === void 0 ? void 0 : _a.memory) ? prettyBytes(row.monit.memory) : 0); }
        },
        port: {
            minWidth: 7,
            get: (row) => { var _a; return (_a = configProcesses.find((data) => data.name === row.name)) === null || _a === void 0 ? void 0 : _a.port; }
        }
    }, {
        printLine: console.log
    });
};
exports.logProcesses = logProcesses;
/**
 * Transform an environment name to be used as a process name
 *
 * @param environmentName
 */
const transformEnvironmentName = (environmentName) => environmentName.trim().toLowerCase().replace(/ /g, '-') || 'mock';
exports.transformEnvironmentName = transformEnvironmentName;
/**
 * Check if a port is already in use
 * @param port
 */
const portInUse = async (port) => await isPortReachable(port);
exports.portInUse = portInUse;
/**
 * Check if a port is valid
 *
 * @param port
 */
const portIsValid = (port) => port >= 0 && port < 65536;
exports.portIsValid = portIsValid;
/**
 * Check if --index or --name flag are provided and
 * prompt user to choose an environment
 *
 * @param flags
 * @param environments
 */
const promptEnvironmentChoice = async (flags, environments) => {
    if (flags.index === undefined && !flags.name) {
        const response = await inquirer_1.prompt([
            {
                name: 'environment',
                message: 'Please select an environment',
                type: 'list',
                choices: environments.map((environment) => ({
                    name: environment.name
                }))
            }
        ]);
        flags.name = response.environment;
    }
    return flags;
};
exports.promptEnvironmentChoice = promptEnvironmentChoice;
//# sourceMappingURL=utils.js.map